import { defineComponent, $prefix, props, setup } from '@opentinyvue/vue-common';
import { renderless, api } from '@opentinyvue/vue-renderless/dropdown-item/vue';
import { iconLeftWardArrow } from '@opentinyvue/vue-icon';
import '@opentinyvue/vue-theme/dropdown-item/index.css';
import { AutoTip } from '@opentinyvue/vue-directive';

function normalizeComponent(scriptExports, render, staticRenderFns, functionalTemplate, injectStyles, scopeId, moduleIdentifier, shadowMode) {
  var options = typeof scriptExports === "function" ? scriptExports.options : scriptExports;
  if (render) {
    options.render = render;
    options.staticRenderFns = staticRenderFns;
    options._compiled = true;
  }
  var hook;
  if (injectStyles) {
    hook = injectStyles;
  }
  if (hook) {
    if (options.functional) {
      options._injectStyles = hook;
      var originalRender = options.render;
      options.render = function renderWithStyleInjection(h, context) {
        hook.call(context);
        return originalRender(h, context);
      };
    } else {
      var existing = options.beforeCreate;
      options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
    }
  }
  return {
    exports: scriptExports,
    options
  };
}

var __vue2_script = defineComponent({
  name: $prefix + "DropdownItem",
  componentName: $prefix + "DropdownItem",
  directives: {
    AutoTip
  },
  emits: ["item-click", "update:modelValue", "change", "closed", "open", "opened", "close", "confirm", "reset"],
  props: [].concat(props, [
    "disabled",
    "divided",
    "icon",
    "itemData",
    "selected",
    "currentIndex",
    "title",
    "titleClass",
    "options",
    "type",
    "label",
    "selectedField",
    "multiStage",
    // tiny新增
    "appendToBody",
    "textField",
    "tip",
    "tipPosition",
    "effect",
    "isMono"
  ]),
  components: {
    IconLeftWardArrow: iconLeftWardArrow()
  },
  setup: function setup$1(props2, context) {
    return setup({
      props: props2,
      context,
      renderless,
      api,
      mono: props2.isMono
    });
  }
});
var render = function render2() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c("li", {
    directives: [{
      name: "auto-tip",
      rawName: "v-auto-tip",
      value: _vm.state.computedTip ? {
        always: true,
        content: _vm.state.computedTip,
        effect: _vm.effect,
        placement: _vm.tipPosition
      } : false,
      expression: "\n    state.computedTip ? { always: true, content: state.computedTip, effect, placement: tipPosition } : false\n  "
    }],
    ref: "dropdownItem",
    class: ["tiny-dropdown-item", "tiny-dropdown-menu__item", _vm.state.sizeClass, _vm.disabled ? "is-disabled" : "", _vm.divided ? "tiny-dropdown-item--divided tiny-dropdown-menu__item--divided" : "", _vm.state.checkedStatus && _vm.selected ? "tiny-dropdown-item--check-status" : "", _vm.itemData.children && _vm.itemData.children.length ? "has-children" : ""],
    attrs: {
      "aria-disabled": _vm.disabled,
      "tabindex": _vm.disabled ? null : -1
    },
    on: {
      "click": function click($event) {
        $event.stopPropagation();
        return _vm.handleClick.apply(null, arguments);
      },
      "mousedown": function mousedown($event) {
        $event.stopPropagation();
      }
    }
  }, [_c("div", {
    staticClass: "tiny-dropdown-item__wrap"
  }, [_vm.itemData.children && _vm.itemData.children.length ? _c("span", {
    staticClass: "tiny-dropdown-item__expand tiny-dropdown-menu__item-expand"
  }, [_c(_vm.state.getIcon, {
    tag: "component"
  })], 1) : _vm._e(), _c("div", {
    staticClass: "tiny-dropdown-item__content tiny-dropdown-menu__item-content"
  }, [_vm.icon ? _c(_vm.icon, {
    tag: "component",
    staticClass: "tiny-svg-size tiny-dropdown-item__pre-icon"
  }) : _vm._e(), _c("span", {
    staticClass: "tiny-dropdown-item__label"
  }, [_vm._t("default", function() {
    return [_c("span", [_vm._v(_vm._s(_vm.label))])];
  }, {
    "itemData": _vm.itemData
  })], 2)], 1), _vm.itemData.children && _vm.itemData.children.length ? _c("ul", {
    class: ["tiny-dropdown-menu", "tiny-dropdown-item--child tiny-dropdown-menu__item--child", _vm.state.popperClass]
  }, _vm._l(_vm.itemData.children, function(item, index) {
    return _c("tiny-dropdown-item", {
      key: index,
      attrs: {
        "label": item[_vm.state.textField],
        "item-data": item,
        "_constants": _vm._constants,
        "icon": item.icon,
        "is-mono": true,
        "disabled": item.disabled,
        "divided": item.divided,
        "tip": item.tip,
        "tip-position": item.tipPosition
      }
    }, [_vm._t("default", null, {
      "itemData": item
    })], 2);
  }), 1) : _vm._e()])]);
};
var staticRenderFns = [];
var __cssModules = {};
var __component__ = /* @__PURE__ */ normalizeComponent(__vue2_script, render, staticRenderFns, false, __vue2_injectStyles);
function __vue2_injectStyles(context) {
  for (var o in __cssModules) {
    this[o] = __cssModules[o];
  }
}
var pc = /* @__PURE__ */ function() {
  return __component__.exports;
}();

export { pc as default };
